@@ -1,4 +1,5 @@
 use anchor_lang::prelude::*;
+use anchor_lang::AccountDeserialize;
 use solana_program::instruction::Instruction;
 
 pub const SEED_TASK: &[u8] = b"task";
@@ -43,6 +44,12 @@ pub struct AccountMetaData {
     pub is_writable: bool,
 }
 
+impl From<Vec<u8>> for Task {
+    fn from(data: Vec<u8>) -> Self {
+        Task::try_deserialize(&mut data.as_slice()).unwrap()
+    }
+}
+
 impl From<Instruction> for InstructionData {
     fn from(instruction: Instruction) -> Self {
         InstructionData {
